
#ifndef __K1874VE7T_HSO_H_
#define __K1874VE7T_HSO_H_

#ifdef __cplusplus
 extern "C" {
#endif


#define ENABLE   1
#define DISABLE  0

#define HSO_PIN_LOW   0
#define HSO_PIN_HIGH  0x20

#define HSO_Timer1   0
#define HSO_Timer2   0x40

#define HSO_Channel_0             0x01  /*!<  HSO 0 */
#define HSO_Channel_1             0x02  /*!<  HSO 1 */
#define HSO_Channel_2             0x04  /*!<  HSO 2 */
#define HSO_Channel_3             0x08  /*!<  HSO 3 */
#define HSO_Channel_4             0x10  /*!<  HSO 4 */
#define HSO_Channel_5             0x20  /*!<  HSO 5 */
#define HSO_All_Channels          0x3F

typedef enum
{
    HSO_CMD_HSO0 = 0,    /*!<    HSO.0 */
    HSO_CMD_HSO1,          /*!<   HSO.1 */
    HSO_CMD_HSO2,          /*!<   HSO.2 */
    HSO_CMD_HSO3,          /*!<   HSO.3 */
    HSO_CMD_HSO4,         /*!<   HSO.4*/
    HSO_CMD_HSO5,         /*!<   HSO.5 */
    HSO_CMD_HSO0_HSO1,    /*!<   HSO.0  HSO.1 */
    HSO_CMD_HSO2_HSO3,    /*!<   HSO.2  HSO.3 */
    HSO_CMD_SWT0,
    HSO_CMD_SWT1,
    HSO_CMD_SWT2,
    HSO_CMD_SWT3,
    HSO_CMD_HSOALL,
    HSO_CMD_Reserved,
    HSO_CMD_Timer2_Reset,
    HSO_CMD_StartADC
}HSO_Command_TypeDef;

/**
  * @brief      BSI Init Structure definition
  */

typedef struct {
        unsigned char  Channels;                                      /*!< This member configures the BSI mode.
                                                                                                                 This parameter is one of @ref BSI_Mode values. */
        unsigned char Interrupt_EN;                                              /*!< This member configures the resetting of errors in TD mode.
                                                                                                         This parameter can be: ENABLE or DISABLE. */
} HSO_InitTypeDef;

typedef struct {
        unsigned char Channel;                                      /*!< This member configures the BSI mode.
                                                                                                                 This parameter is one of @ref BSI_Mode values. */
        unsigned int  Time;                                              /*!< This member configures the resetting of errors in TD mode.
                                                                                                         This parameter can be: ENABLE or DISABLE. */
        unsigned char  Interrupt_EN;                                               /*!< This member configures the BSI clock divider.
                                                                                                                 This parameter is number from 0 to 16.
                                                                                                                 For XTALL: DIV = Fxtall / 8,
                                                                                                                 For EXT_CLK: DIV = FextClk / 7.
                                                                                                                 but the stability of reception is not guaranteed.*/
        unsigned char  CAM_Lock;                                  /*!< This member configures the ask delay.
                                                                                                                 This parameter is value from 0 to 0x3 */
        unsigned char  TimerSel;                                  /*!< This member configures the level TxD on inactive state.
                                                                                                                 This parameter can be: ENABLE or DISABLE. */
        unsigned char  Pin_State;                                 /*!< This member configures the start address in message memory
                                                                                                                on which the control word of the first message block is located.
                                                                                                                 This parameter is value from 0x0800 to 0x1FF0 */
        unsigned char  Command;                                 /*!< This member configures the  time interval by which the bus controller
                                                                                                                divides the transmitted messages.
                                                                                                                 This parameter is value from 0 to 65535 */
} HSO_EventTypeDef;

#ifdef __cplusplus
}
#endif

#endif /* 1874VEXX_BSI_H_ */

